==> tarball69_downloader-0.7.tar.gz: tarball69_downloader-0.7/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(

    name="tarball69_downloader",

    version="0.7",     # must be PEP 440 compliant by now!

    packages=find_packages(),
    requires=[],
    description="downloader - a Python module for downloading files "
        "from the internet.",
    author="Raphaël SEBAN",
    author_email="motus@laposte.net",
    maintainer="Raphaël SEBAN",
    maintainer_email="motus@laposte.net",
    url="https://github.com/tarball69/downloader",
    download_url="https://github.com/tarball69/downloader/releases",
    keywords=["download", "downloader", "file", "http", "internet",
    "tkinter", "dialog"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Other Environment",
        "Environment :: MacOS X",
        "Environment :: Win32 (MS Windows)",
        "Environment :: X11 Applications",
        "Intended Audience :: Developers",
        "License :: OSI Approved",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    license="Licensed under the MIT License.",
    long_description="""

downloader - a Python module for downloading files from the internet.

This project is **freefullware** oriented.


Freefullware
------------

What is a freefullware?

A **freefullware** is a new kind of software:

* Free as in Freedom;
* Free of charge (gratis);
* Ad-free (no advertisement at all);
* Donate-free (no 'Donate' button at all);
* 100% virus-free;
* no counterpart at all;
* really absolutely free.

Just get it and enjoy.

That's all, folks!


Quick installation
------------------

On a Linux shell console::

    python3 /usr/bin/pip3 install -U tarball69_downloader

On a MS-DOS(tm) console prompt::

    C:\Python3.4\Scripts\pip3.exe install -U tarball69_downloader

Browse to your own Python3's pip3.exe installation path and adapt
command if this one doesn't work as expected.


Basic usage
-----------

On a Linux shell console::

    python3
    >>> import downloader
    >>> downloader.run_demo()
    >>> from downloader import easy_tool
    >>> easy_tool.run_tool()

On a MS-DOS(tm) console prompt::

    py -3
    >>> import downloader
    >>> downloader.run_demo()
    >>> from downloader import easy_tool
    >>> easy_tool.run_tool()

Have fun!
"""

) # end setup

==> tarball69_downloader-0.7.1.tar.gz: tarball69_downloader-0.7.1/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(

    name="tarball69_downloader",

    version="0.7.1",     # must be PEP 440 compliant by now!

    packages=find_packages(),
    requires=[],
    description="downloader - a Python module for downloading files "
        "from the internet.",
    author="Raphaël SEBAN",
    author_email="motus@laposte.net",
    maintainer="Raphaël SEBAN",
    maintainer_email="motus@laposte.net",
    url="https://github.com/tarball69/downloader",
    download_url="https://github.com/tarball69/downloader/releases",
    keywords=["download", "downloader", "file", "http", "internet",
    "tkinter", "dialog"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Other Environment",
        "Environment :: MacOS X",
        "Environment :: Win32 (MS Windows)",
        "Environment :: X11 Applications",
        "Intended Audience :: Developers",
        "License :: OSI Approved",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    license="Licensed under the MIT License.",
    long_description="""

downloader - a Python module for downloading files from the internet.

This project is **freefullware** oriented.


Freefullware
------------

What is a freefullware?

A **freefullware** is a new kind of software:

* Free as in Freedom;
* Free of charge (gratis);
* Ad-free (no advertisement at all);
* Donate-free (no 'Donate' button at all);
* 100% virus-free;
* no counterpart at all;
* really absolutely free.

Just get it and enjoy.

That's all, folks!


Quick installation
------------------

On a Linux shell console::

    python3 /usr/bin/pip3 install -U tarball69_downloader

On a MS-DOS(tm) console prompt::

    C:\Python3.4\Scripts\pip3.exe install -U tarball69_downloader

Browse to your own Python3's pip3.exe installation path and adapt
command if this one doesn't work as expected.


Basic usage
-----------

On a Linux shell console::

    python3
    >>> import downloader
    >>> downloader.run_demo()
    >>> from downloader import easy_tool
    >>> easy_tool.run_tool()

On a MS-DOS(tm) console prompt::

    py -3
    >>> import downloader
    >>> downloader.run_demo()
    >>> from downloader import easy_tool
    >>> easy_tool.run_tool()

Have fun!
"""

) # end setup
